@@ -1,8 +1,8 @@
-# -*- coding: utf-8 -*-
+# type: ignore
 
 """Command line interface for PyStow."""
 
 from .cli import main
 
-if __name__ == '__main__':
+if __name__ == "__main__":
     main()
