@@ -44,12 +44,14 @@ from .constants import (
     PYSTOW_NAME_ENVVAR,
     PYSTOW_USE_APPDIRS,
     README_TEXT,
+    TimeoutHint,
 )
 
 if TYPE_CHECKING:
     import _csv
 
     import botocore.client
+    import bs4
     import lxml.etree
     import numpy.typing
     import pandas
@@ -69,12 +71,14 @@ __all__ = [
     "get_base",
     "get_commit",
     "get_df_io",
+    "get_hash_hexdigest",
     "get_hashes",
     "get_hexdigests_remote",
     "get_home",
     "get_name",
     "get_np_io",
     "get_offending_hexdigests",
+    "get_soup",
     "getenv_path",
     "gunzip",
     "mkdir",
@@ -283,6 +287,17 @@ def get_hashes(
     return algorithms
 
 
+def get_hash_hexdigest(
+    path: str | Path,
+    name: str,
+    *,
+    chunk_size: int | None = None,
+) -> str:
+    """Get a hash digest for a single hash."""
+    r = get_hashes(path, [name], chunk_size=chunk_size)
+    return r[name].hexdigest()
+
+
 def raise_on_digest_mismatch(
     *,
     path: Path,
@@ -1397,3 +1412,32 @@ def safe_open_dict_reader(
             yield csv.DictReader(file, delimiter=delimiter, **kwargs)
     else:
         yield csv.DictReader(f, delimiter=delimiter, **kwargs)
+
+
+def get_soup(
+    url: str,
+    *,
+    verify: bool = True,
+    timeout: TimeoutHint | None = None,
+    user_agent: str | None = None,
+) -> bs4.BeautifulSoup:
+    """Get a beautiful soup parsed version of the given web page.
+
+    :param url: The URL to download and parse with BeautifulSoup
+    :param verify: Should SSL be used? This is almost always true, except for Ensembl,
+        which makes a big pain
+    :param timeout: How many integer seconds to wait for a response? Defaults to 15 if
+        none given.
+    :param user_agent: A custom user-agent to set, e.g., to avoid anti-crawling
+        mechanisms
+
+    :returns: A BeautifulSoup object
+    """
+    from bs4 import BeautifulSoup
+
+    headers = {}
+    if user_agent:
+        headers["User-Agent"] = user_agent
+    res = requests.get(url, verify=verify, timeout=timeout or 15, headers=headers)
+    soup = BeautifulSoup(res.text, features="html.parser")
+    return soup
